@@ -70,7 +70,7 @@ class DiegoOperator(PythonOperator):
         print(f"File sent to Diego to path {file_path}")
         print(f"Diego response {response.text}")
 
-        return response.json()['replyId']
+        return response
 
     def __upload_df_to_s3_temp(self, df: pd.DataFrame, path, part_number, pandas_kwargs=None):
         if pandas_kwargs is None:
